@@ -1,6 +1,6 @@
 from typing import List
 
-GITIGNORE = '/venv\n/static\n/media\n__pycache__\n*.sqlite*\n*.log\n.env'
+GITIGNORE: str = '/venv\n/static\n/media\n__pycache__\n*.sqlite*\n*.log\n.env'
 
 ENV_EXAMPLE: str = '''
 SECRET_KEY=
